#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-6vueh4P5JnC4tBGPWX3qxI
key:                  summoner-tui-2.0.1.1-6vueh4P5JnC4tBGPWX3qxI
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  2dbadf71b91238a7eec019fb2d1488ec
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-8.10.2/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/summoner-tui-2.0.1.1
hs-libraries:         HSsummoner-tui-2.0.1.1-6vueh4P5JnC4tBGPWX3qxI
depends:
    base-4.14.1.0 relude-0.7.0.0-JK5pn0xx3Mp2lgEsdDZ45
    brick-0.57.1-CgnbF1kysIpDX7juTDp5dq
    colourista-0.1.0.0-DnavSMQsXRALUonxX0ENCx directory-1.3.6.0
    microlens-0.4.11.2-9caS3Frz8K54yIHXMtlddL
    microlens-th-0.4.3.6-M0D4zBEXIjEa75KR5Tb4o
    summoner-2.0.1.1-3UqIvYEd1Hi4kuOsbTMtXs text-1.2.3.2
    validation-selective-0.1.0.0-16F0uF2bAM4Byznd2iHYbk
    vty-5.32-4R5sEEjUqyYI0LiA4mStcF

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

